@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -113,7 +113,7 @@ MagickExport MagickBooleanType AcquireImageColormap(Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (colors > MaxColormapSize)
     {
@@ -149,7 +149,8 @@ MagickExport MagickBooleanType AcquireImageColormap(Image *image,
     image->colormap[i].alpha=(MagickRealType) OpaqueAlpha;
     image->colormap[i].alpha_trait=BlendPixelTrait;
   }
-  return(SetImageStorageClass(image,PseudoClass,exception));
+  image->storage_class=PseudoClass;
+  return(MagickTrue);
 }
 
 /*
@@ -198,7 +199,7 @@ MagickExport MagickBooleanType CycleColormapImage(Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->storage_class == DirectClass)
     (void) SetImageType(image,PaletteType,exception);
@@ -313,9 +314,9 @@ MagickExport MagickBooleanType SortColormapByIntensity(Image *image,
     *pixels;
 
   assert(image != (Image *) NULL);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(image->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (image->storage_class != PseudoClass)
     return(MagickTrue);
   /*
