@@ -34,7 +34,7 @@
 %
 %
 */
-
+
 /*
   Include declarations.
 */
@@ -77,14 +77,14 @@ typedef struct MemoryManagerInfo
   ExceptionInfo
     *exception;
 } MemoryManagerInfo;
-
+
 #if defined(MAGICKCORE_JXL_DELEGATE)
 /*
   Forward declarations.
 */
 static MagickBooleanType
   WriteJXLImage(const ImageInfo *,Image *,ExceptionInfo *);
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -119,7 +119,7 @@ static MagickBooleanType IsJXL(const unsigned char *magick,const size_t length)
     return(MagickFalse);
   return(MagickTrue);
 }
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -620,6 +620,19 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
       offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+2)) << 8;
       offset|=(unsigned int) (*(GetStringInfoDatum(snippet)+3)) << 0;
       snippet=DestroyStringInfo(snippet);
+      /*
+        Strip any EOI marker if payload starts with a JPEG marker.
+      */
+      size_t exif_length = GetStringInfoLength(exif_profile);
+      unsigned char *exif_datum = GetStringInfoDatum(exif_profile);
+      if (exif_length > 2 && 
+          (memcmp(exif_datum, "\xff\xd8", 2) == 0 ||
+           memcmp(exif_datum, "\xff\xe1", 2) == 0) &&
+          memcmp(exif_datum+exif_length-2, "\xff\xd9", 2) == 0)
+        SetStringInfoLength(exif_profile, exif_length-2);
+      /*
+        Skip to actual Exif payload.
+      */
       if (offset < GetStringInfoLength(exif_profile))
         (void) DestroyStringInfo(SplitStringInfo(exif_profile,
           offset));
@@ -645,7 +658,7 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   return(GetFirstImageInList(image));
 }
 #endif
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -695,7 +708,7 @@ ModuleExport size_t RegisterJXLImage(void)
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -719,7 +732,7 @@ ModuleExport void UnregisterJXLImage(void)
 {
   (void) UnregisterMagickInfo("JXL");
 }
-
+
 #if defined(MAGICKCORE_JXL_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
